//==========================================================================
//
// mc9328mx21.h
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
// Contributors: Luis Torrico, Cogent Computer Systems, Inc.
// Date:         09/18/2005
// Description:  This file contains register base addresses and offsets
//				 and access macros for the MC9328MX21 on-chip peripherals
//				 This was copied from the mc9328mxl.h and peripherals not
//				 used by UMON have not been tested (and may not be defined).
//			     Use these defines with caution!!
//

#include "bits.h"

// ------------------------------------------
// CLOCK - Clock Module
#define CLOCK_BASE_ADD		IMMRBAR_BASE_ADD + 0x00F00
#define CLOCK_REG(_x_)		*(vulong *)(CLOCK_BASE_ADD + _x_)
#define CLOCK_SPMR 			0x00 	// System PLL Mode Register
#define CLOCK_SCCR1			0x04 	// System Clock Control Register 1
#define CLOCK_SCCR2			0x08 	// System Clock Control Register 2
#define CLOCK_SCFR1			0x0C 	// System Clock Frequency Register 1
#define CLOCK_SCFR2			0x10 	// System Clock Frequency Register 2
#define CLOCK_BCR			0x18 	// Bread Crumb Register
#define CLOCK_P0CCR			0x1C 	// PSC0 Clock Control Register
#define CLOCK_P1CCR			0x20 	// PSC1 Clock Control Register
#define CLOCK_P2CCR			0x24 	// PSC2 Clock Control Register
#define CLOCK_P3CCR			0x28 	// PSC3 Clock Control Register
#define CLOCK_P4CCR			0x2C 	// PSC4 Clock Control Register
#define CLOCK_P5CCR			0x30 	// PSC5 Clock Control Register
#define CLOCK_P6CCR			0x34 	// PSC6 Clock Control Register
#define CLOCK_P7CCR			0x38 	// PSC7 Clock Control Register
#define CLOCK_P8CCR			0x3C 	// PSC8 Clock Control Register
#define CLOCK_P9CCR			0x40 	// PSC9 Clock Control Register
#define CLOCK_P10CCR		0x44 	// PSC10 Clock Control Register
#define CLOCK_P11CCR		0x48 	// PSC11 Clock Control Register
#define CLOCK_SPCCR			0x4C 	// SPDIF Clock Control Register
#define CLOCK_CCCR			0x50 	// CFM Clock Control Register
#define CLOCK_DCCR			0x54 	// DIU Clock Control Register

//---------------------------------------
// Programmable Serial Controller (PSC)
// additional PSC defines are in mpc5121e_psc.h
#define PSC0_BASE_ADD		IMMRBAR_BASE_ADD + 0x11000
#define PSC1_BASE_ADD		IMMRBAR_BASE_ADD + 0x11100
#define PSC2_BASE_ADD		IMMRBAR_BASE_ADD + 0x11200
#define PSC3_BASE_ADD		IMMRBAR_BASE_ADD + 0x11300
#define PSC4_BASE_ADD		IMMRBAR_BASE_ADD + 0x11400
#define PSC5_BASE_ADD		IMMRBAR_BASE_ADD + 0x11500
#define PSC6_BASE_ADD		IMMRBAR_BASE_ADD + 0x11600
#define PSC7_BASE_ADD		IMMRBAR_BASE_ADD + 0x11700
#define PSC8_BASE_ADD		IMMRBAR_BASE_ADD + 0x11800
#define PSC9_BASE_ADD		IMMRBAR_BASE_ADD + 0x11900
#define PSC10_BASE_ADD		IMMRBAR_BASE_ADD + 0x11A00
#define PSC11_BASE_ADD		IMMRBAR_BASE_ADD + 0x11B00
#define PSC0_REG_8(_x_)		*(vuchar *)(PSC0_BASE_ADD + _x_)
#define PSC0_REG_16(_x_)	*(vuint *)(PSC0_BASE_ADD + _x_)
#define PSC0_REG_32(_x_)	*(vulong *)(PSC0_BASE_ADD + _x_)
#define PSC1_REG_8(_x_)		*(vuchar *)(PSC1_BASE_ADD + _x_)
#define PSC1_REG_16(_x_)	*(vuint *)(PSC1_BASE_ADD + _x_)
#define PSC1_REG_32(_x_)	*(vulong *)(PSC1_BASE_ADD + _x_)
#define PSC2_REG_8(_x_)		*(vuchar *)(PSC2_BASE_ADD + _x_)
#define PSC2_REG_16(_x_)	*(vuint *)(PSC2_BASE_ADD + _x_)
#define PSC2_REG_32(_x_)	*(vulong *)(PSC2_BASE_ADD + _x_)
#define PSC3_REG_8(_x_)		*(vuchar *)(PSC3_BASE_ADD + _x_)
#define PSC3_REG_16(_x_)	*(vuint *)(PSC3_BASE_ADD + _x_)
#define PSC3_REG_32(_x_)	*(vulong *)(PSC3_BASE_ADD + _x_)
#define PSC4_REG_8(_x_)		*(vuchar *)(PSC4_BASE_ADD + _x_)
#define PSC4_REG_16(_x_)	*(vuint *)(PSC4_BASE_ADD + _x_)
#define PSC4_REG_32(_x_)	*(vulong *)(PSC4_BASE_ADD + _x_)
#define PSC5_REG_8(_x_)		*(vuchar *)(PSC5_BASE_ADD + _x_)
#define PSC5_REG_16(_x_)	*(vuint *)(PSC5_BASE_ADD + _x_)
#define PSC5_REG_32(_x_)	*(vulong *)(PSC5_BASE_ADD + _x_)
#define PSC6_REG_8(_x_)		*(vuchar *)(PSC6_BASE_ADD + _x_)
#define PSC6_REG_16(_x_)	*(vuint *)(PSC6_BASE_ADD + _x_)
#define PSC6_REG_32(_x_)	*(vulong *)(PSC6_BASE_ADD + _x_)
#define PSC7_REG_8(_x_)		*(vuchar *)(PSC7_BASE_ADD + _x_)
#define PSC7_REG_16(_x_)	*(vuint *)(PSC7_BASE_ADD + _x_)
#define PSC7_REG_32(_x_)	*(vulong *)(PSC7_BASE_ADD + _x_)
#define PSC8_REG_8(_x_)		*(vuchar *)(PSC8_BASE_ADD + _x_)
#define PSC8_REG_16(_x_)	*(vuint *)(PSC8_BASE_ADD + _x_)
#define PSC8_REG_32(_x_)	*(vulong *)(PSC8_BASE_ADD + _x_)
#define PSC9_REG_8(_x_)		*(vuchar *)(PSC9_BASE_ADD + _x_)
#define PSC9_REG_16(_x_)	*(vuint *)(PSC9_BASE_ADD + _x_)
#define PSC9_REG_32(_x_)	*(vulong *)(PSC9_BASE_ADD + _x_)
#define PSC10_REG_8(_x_)	*(vuchar *)(PSC10_BASE_ADD + _x_)
#define PSC10_REG_16(_x_)	*(vuint *)(PSC10_BASE_ADD + _x_)
#define PSC10_REG_32(_x_)	*(vulong *)(PSC10_BASE_ADD + _x_)
#define PSC11_REG_8(_x_)	*(vuchar *)(PSC11_BASE_ADD + _x_)
#define PSC11_REG_16(_x_)	*(vuint *)(PSC11_BASE_ADD + _x_)
#define PSC11_REG_32(_x_)	*(vulong *)(PSC11_BASE_ADD + _x_)

//---------------------------------------
// PSC Centralized FIFO Controller (FIFOC)
// additional defines are in mpc5121e_psc.h
#define FIFOC_BASE_ADD		IMMRBAR_BASE_ADD + 0xF00
#define FIFOC_REG(_x_)		*(vulong *)(FIFOC_BASE_ADD + _x_)
#define FIFO_CMD			0x00 	// Command Register
#define FIFO_ISR 			0x04 	// FIFO Interrupt Status Register

//---------------------------------------
// DMAC - Direct Memory Access Controller General Registers
#define DMA_BASE_ADD		0x10001000
#define DMA_REG(_x_)		*(vulong *)(DMA_BASE_ADD + _x_)
#define DMA_CR 				0x00 	// Control Register
#define DMA_ISR 			0x04 	// Interrupt Status Register
#define DMA_IMR 			0x08 	// Interrupt Mask Register
#define DMA_BTOSR 			0x0C 	// Burst Time-Out Status Register
#define DMA_RTOSR 			0x10 	// Request Time-Out Status Register
#define DMA_TESR 			0x14 	// Transfer Error Status Register
#define DMA_BOSR 			0x18 	// Buffer Overflow Status Register
#define DMA_BTOCR 			0x1C 	// Burst Tome-Out Control Register

//---------------------------------------
// DMAC - Direct Memory Access Controller Channel Registers
#define DMA_BASE_ADD		0x10001000
#define DMAC0_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x080 + _x_)
#define DMAC1_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x0C0 + _x_)
#define DMAC2_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x100 + _x_)
#define DMAC3_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x140 + _x_)
#define DMAC4_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x180 + _x_)
#define DMAC5_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x1C0 + _x_)
#define DMAC6_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x200 + _x_)
#define DMAC7_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x240 + _x_)
#define DMAC8_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x280 + _x_)
#define DMAC9_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x2C0 + _x_)
#define DMAC10_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x300 + _x_)
#define DMAC11_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x340 + _x_)
#define DMAC12_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x380 + _x_)
#define DMAC13_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x3C0 + _x_)
#define DMAC14_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x400 + _x_)
#define DMAC15_REG(_x_)		*(vulong *)(DMA_BASE_ADD + 0x440 + _x_)
#define DMAC_SAR 			0x00 	// Source Address Register
#define DMAC_DAR 			0x04 	// Destination Address Register
#define DMAC_CNTR 			0x08 	// Count Register
#define DMAC_CR 			0x0C 	// Control Register
#define DMAC_RSSR 			0x10 	// Request Source Select Register
#define DMAC_BLR 			0x14 	// Burst Length Register
#define DMAC_RTOR 			0x18 	// Request Time-Out Register
#define DMAC_BUCR 			0x18 	// Bus Utilization Control Register
#define DMAC_COUNTR 		0x1C 	// Counter Register

//---------------------------------------
// SPI -  Serial Peripheral Interface
#define SPI1_BASE_ADD		0x1000E000
#define SPI2_BASE_ADD		0x1000F000
#define SPI3_BASE_ADD		0x10017000
#define SPI1_REG(_x_)		*(vulong *)(SPI1_BASE_ADD + _x_)
#define SPI2_REG(_x_)		*(vulong *)(SPI2_BASE_ADD + _x_)
#define SPI3_REG(_x_)		*(vulong *)(SPI3_BASE_ADD + _x_)
#define SPI_RXD 			0x00 	// Receive Data Register
#define SPI_TXD 			0x04 	// Transmit Data Register
#define SPI_CTRL 			0x08 	// Control Register
#define SPI_INT 			0x0C 	// Interrupt Control/Status Register
#define SPI_TEST 			0x10 	// Test Register
#define SPI_PERIOD 			0x14 	// Sample Period Control Register
#define SPI_DMA 			0x18 	// DMA Register
#define SPI_RESET 			0x1C 	// Soft Reset Register

// ------------------------------------------
// SSI - Synchronous Serial Interface
#define SSI1_BASE_ADD		0x10010000
#define SSI2_BASE_ADD		0x10011000
#define SSI1_REG(_x_)		*(vulong *)(SSI1_BASE_ADD + _x_)
#define SSI2_REG(_x_)		*(vulong *)(SSI2_BASE_ADD + _x_)
#define SSI_TXD0 			0x00 	// Transmit Data Register
#define SSI_TXD1 			0x04 	// Transmit Data Register
#define SSI_RXD0 			0x08 	// Receive Data Register
#define SSI_RXD1 			0x0C 	// Receive Data Register
#define SSI_CR	 			0x10 	// Control Register
#define SSI_ISR 			0x14 	// Interrupt Status Register
#define SSI_IER 			0x18 	// Interrupt Enable Register
#define SSI_TCR 			0x1C 	// Transmit Configuration Register
#define SSI_RCR 			0x20 	// Receive Configuration Register
#define SSI_TCCR 			0x24 	// Transmit Clock Control Register
#define SSI_RCCR 			0x28 	// Receive Clock Control Register
#define SSI_FCSR 			0x2C 	// FIFO Control/Status Register
#define SSI_TR	 			0x30 	// Test Register
#define SSI_OR 				0x24 	// Option Register
#define SSI_AC97CR			0x38 	// AC97 Control Register
#define SSI_AC97CMDAR		0x3C 	// AC97 Command Address Register
#define SSI_AC97CMDDR		0x40 	// AC97 Command Data Register
#define SSI_AC97TR			0x44 	// AC97 Tag Register
#define SSI_TTSR 			0x48 	// Transmit Time Slot Mask Register
#define SSI_RTSR 			0x4C 	// Receive Time Slot Mask Register

// ------------------------------------------
// GPIO - General Purpose I/O
#define GPIO_BASE_ADD		0x10015000
#define GPIO_PMASK 			0x10056000 	// GPIO Port Interrupt Mask for all ports
#define GPIOA_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x000 + _x_)
#define GPIOB_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x100 + _x_)
#define GPIOC_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x200 + _x_)
#define GPIOD_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x300 + _x_)
#define GPIOE_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x400 + _x_)
#define GPIOF_REG(_x_)		*(vulong *)(GPIO_BASE_ADD + 0x500 + _x_)
#define GPIO_DDIR 			0x00 	// Data Direction Register
#define GPIO_OCR1 			0x04 	// Output Configuration Register 1
#define GPIO_OCR2 			0x08 	// Output Configuration Register 2
#define GPIO_ICONFA1 		0x0C 	// Input Configuration Register A1
#define GPIO_ICONFA2 		0x10 	// Input Configuration Register A2
#define GPIO_ICONFB1 		0x14 	// Input Configuration Register B1
#define GPIO_ICONFB2 		0x18 	// Input Configuration Register B2
#define GPIO_DR 			0x1C 	// Data Register
#define GPIO_GIUS 			0x20 	// GPIO In Use Register
#define GPIO_SSR 			0x24 	// Sample Status Register
#define GPIO_ICR1 			0x28 	// Interrupt Configuration Register 1
#define GPIO_ICR2 			0x2C 	// Interrupt Configuration Register 2
#define GPIO_IMR 			0x30 	// Interrupt Mask Register
#define GPIO_ISR 			0x34 	// Interrupt Status Register
#define GPIO_GPR 			0x38 	// General Purpose Register
#define GPIO_SWR 			0x3C 	// Software Reset Register
#define GPIO_PUEN 			0x40 	// Pull_Up Enable Register

// ------------------------------------------
// LCDC - LCD Controller
// Individual bit and register defines are in mc9328mx21_lcd.h
#define LCDC_BASE_ADD		0x10021000
#define LCDC_REG(_x_)		*(vulong *)(LCDC_BASE_ADD + _x_)

// ------------------------------------------
// EIM - External Interface Module
// Individual bit and register defines are in mc9328mx21_mem.h
#define EIM_BASE_ADD		0xDF001000
#define EIM_REG(_x_)		*(vulong *)(EIM_BASE_ADD + _x_)

// ------------------------------------------
// SDRAMC - SDRAM Controller
#define SDRAMC_BASE_ADD		0xDF000000
#define SDRAMC_REG(_x_)		*(vulong *)(SDRAMC_BASE_ADD + _x_)
#define SDRAMC_CTL0 		0x00 	// SDRAM 0 Control Register
#define SDRAMC_CTL1 		0x04 	// SDRAM 1 Control Register
#define SDRAMC_MISC 		0x14 	// Miscellaneous Register
#define SDRAMC_RST 			0x18 	// SDRAM Reset Register


