//==========================================================================
//
// mpc5121e_psc.h
//
// Author(s):    Luis Torrico, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         10/06/2008
// Description:  This file contains offsets and bit defines
//				 for the MPC5121e on-chip PSC's
//

#include "bits.h"

// Register offsets
#define PSC_MR1			0x00		// Mode Register 1
#define PSC_MR2			0x00		// Mode Register 2
#define PSC_SR			0x04		// Status Register 				
#define PSC_CSR			0x04		// Clock Select Register 				
#define PSC_CR			0x08		// Command Register 				
#define PSC_RXB			0x0C		// Rx Buffer Register 				
#define PSC_TXB			0x0C		// Tx Buffer Register 			
#define PSC_IPCR		0x10		// Input Port Change Register 				
#define PSC_ACR			0x10		// Auxiliary Control Register 				
#define PSC_ISR			0x14		// Interrupt Status Register 		
#define PSC_IMR			0x14		// Interrupt Mask Register 			
#define PSC_CTUR		0x18		// Counter Timer Upper Register			
#define PSC_CTLR		0x1C		// Counter Timer Lower Register 			
#define PSC_CCR			0x20		// Codec Clock Register 			
#define PSC_AC97_SLOT	0x24		// AC97 Slots Register 
#define PSC_AC97_CMD	0x28		// AC97 Command register
#define PSC_AC97_DATA	0x2C		// AC97 Status Data Register 
#define PSC_IVR			0x30		// Interrupt Vector Register 
#define PSC_IP			0x34		// Input Port Register 	
#define PSC_OP1			0x38		// Output Port 1 Bit Set Register 	
#define PSC_OP0			0x3C		// Output Port 0 Bit Set Register
#define PSC_SICR		0x40		// Serial Interface Control Register 	

// Bit defines - Refer to MPC5121e Users Manual for more detailed information
//
// PSC_MR1 - Mode Register 1 : UART mode only 				
#define PSC_RX_RTS		BIT7		// 1 = RTS is negated if the PSC FIFO is full
#define PSC_TO_EN		BIT5		// 1 = Time out counter is enabled
#define PSC_PM_WP		(0 << 3)	// Parity Mode = With Parity
#define PSC_PM_FP		(1 << 3)	// Parity Mode = Force parity
#define PSC_PM_NP		(2 << 3)	// Parity Mode = No Parity
#define PSC_PM_MM		(3 << 3)	// Parity Mode = Multidrop mode
#define PSC_PT			BIT2		// Parity Type
#define PSC_B_C_5		(0 << 0)	// Selects 5 bits per character to be sent
#define PSC_B_C_6		(1 << 0)	// Selects 6 bits per character to be sent
#define PSC_B_C_7		(2 << 0)	// Selects 7 bits per character to be sent
#define PSC_B_C_8		(3 << 0)	// Selects 8 bits per character to be sent

// PSC_MR2 - Mode Register 2 				
#define PSC_CM_NORM		(0 << 6)			// Channel Mode is Normal
#define PSC_CM_AUTO		(1 << 6)			// Channel Mode is Automatic Echo
#define PSC_CM_LLB		(2 << 6)			// Channel Mode is Local Loop-back
#define PSC_CM_RLB		(3 << 6)			// Channel Mode is Remote Loop-back
#define PSC_TX_RTS		BIT5				// Transmitter ready-to-send, UART mode only
#define PSC_TX_CTS		BIT4				// Transmitter clear-to-send, UART mode only
#define PSC_SB(_x_)		((_x_ & 0xf) << 0)	// Stop bit length control
#define PSC_RX_1		(0 << 2)			// 1 RX channel, Codec mode only
#define PSC_RX_2		(1 << 2)			// 2 RX channel, Codec mode only
#define PSC_RX_3		(2 << 2)			// 3 RX channel, Codec mode only
#define PSC_TX_1		(0 << 0)			// 1 TX channel, Codec mode only
#define PSC_TX_2		(1 << 0)			// 2 TX channel, Codec mode only
#define PSC_TX_3		(2 << 0)			// 3 TX channel, Codec mode only

// PSC_SR - Status Register : Read-only for UART mode				
//#define PSC_USR_RB			BIT15		// 1 = Received Break
//#define PSC_USR_FE			BIT14		// 1 = Framing error detected
//#define PSC_USR_PE			BIT13		// 1 = Parity error	detected
//#define PSC_USR_ORERR		BIT12		// 1 = Overrun error detected
//#define PSC_USR_TXEMP		BIT11		// 1 = Transmitter empty
//#define PSC_USR_CDE			BIT7		// 1 = No DCD error
//#define PSC_USR_ERROR		BIT6		// 1 = Error status detected
//#define PSC_USR_TIMEOUT		BIT5		// 1 = Time out event detected

// PSC_SR - Status Register : Read-only for UART mode				
#define PSC_USR_RB			BIT15		// 1 = Received Break
//#define PSC_USR_FE			BIT14		// 1 = Framing error detected
//#define PSC_USR_PE			BIT13		// 1 = Parity error	detected
//#define PSC_USR_ORERR		BIT12		// 1 = Overrun error detected
//#define PSC_USR_TXEMP		BIT11		// 1 = Transmitter empty
#define PSC_USR_TXEMP		0x0800		// 1 = Transmitter empty
//#define PSC_USR_CDE			BIT7		// 1 = No DCD error
//#define PSC_USR_ERROR		BIT6		// 1 = Error status detected
//#define PSC_USR_TIMEOUT		BIT5		// 1 = Time out event detected

// PSC_SR - Status Register : Read-only for other modes				
#define PSC_OSR_ORERR		BIT12		// 1 = Overrun error detected
#define PSC_OSR_URERR		BIT11		// 1 = Underrun error detected
#define PSC_OSR_ERROR		BIT6		// 1 = Error status detected
#define PSC_OSR_CMD_SEND	BIT3		// 1 = Command send ready
#define PSC_OSR_DATA_OVR	BIT2		// 1 = Receive status data overwrite detected
#define PSC_OSR_DATA_VALID	BIT1		// 1 = Receive Status Data valid
#define PSC_OSR_U_RX_SLOT	BIT0		// 1 = Unexpected receive slot detected
			
// PSC_CSR - Clock Select Register : UART mode only 				
#define PSC_RCS(_x_)	((_x_ & 0xf) << 12)	// Receive Clock Select Register
#define PSC_TCS(_x_)	((_x_ & 0xf) << 8)	// Transmitter Clock Select Register

// PSC_CR - Command Register 				
#define PSC_MISC(_x_)	((_x_ & 0x7) << 4)	// NISC field
#define PSC_TC(_x_)		((_x_ & 0x3) << 2)	// Transmitter Field
#define PSC_RC(_x_)		((_x_ & 0x3) << 0)	// Receiver field

// PSC_RB - Rx Buffer Register
#define PSC_RX_BUFF(_x_)		((_x_ & 0xffffffff) << 0)	// Receive Buffer

// PSC_TB - Tx Buffer Register
#define PSC_TX_BUFF(_x_)		((_x_ & 0xffffffff) << 0)	// Transmitter Buffer

// PSC_CTUR - Counter Timer Upper Register
//#define PSC_CTUR_UPPER(_x_)		((_x_ & 0xf) << 0)	// baudrate prescaler value in UART/SPI mode

// PSC_CTLR - Counter Timer Lower Register
//#define PSC_CTLR_LOWER(_x_)		((_x_ & 0xf) << 0)	// Baudrate prescaler value in UART mode

// PSC_SICR - Serial Interface Control Register 				
#define PSC_SPI			BIT23		// 1 = PSC behaves as SPI in Codec mode
#define PSC_MSTR		BIT22		// 1 = PSC behaves as SPI Master in Codec mode
#define PSC_CPOL		BIT21		// 1 = SPI Clock is Active-high	in Codec mode
#define PSC_CPHA		BIT20		// 1 = SPI Clock starts with first edge of SCK in Codec mode
#define PSC_EOF			BIT19		// 1 = Use End-of_Frame flag in Codec mode
#define PSC_OB_EN		BIT16		// 1 = Output Buffer enabled
#define PSC_GEN_CLK		BIT15		// 1 = Generate Bit Clock and FrameSync in Codec mode
#define PSC_I2S			BIT14		// 1 = PSC works in Codec I2S mode
#define PSC_CLK_POL		BIT13		// 1 = data sampled on rising and out on falling edge of BCLK
#define PSC_SNC_POL		BIT12		// 1 = FrameSync is high true in Codec SPI mode, Frame start LRCK high in I2S mode
#define PSC_ESAI		BIT9		// 1 = PSC supports Enhanced Serail Audio Interface in Codec mode
#define PSC_AC97_EN		BIT8		// 1 = AC97 tx and rx the data, only if AC97 selected
#define PSC_ACRB		BIT7		// 1 = Transmitter stays in current mode, AC97 mode
#define PSC_AWR			BIT6		// 1 = Force 1 on RTS output/AC97 Framesync, AC97 mode
#define PSC_DTS1		BIT5		// 1 = Delay of 1 clock cycle, Codec mode
#define PSC_SHDIR		BIT4		// 1 = shift direction is LSB
#define PSC_SIM(_x_)			((_x_ & 0xf) << 0)	// PSC operation mode

//-------------------------------------------------------------------------
// FIFOC - PSC Centralized FIFO Controller				
//-------------------------------------------------------------------------

#define PSC3_TX_CMD		0x80		// 
#define PSC3_RX_CMD		0xC0		// 
#define PSC3_TX_IMR		0x90		//  				
#define PSC3_RX_IMR		0xD0		//  				
#define PSC3_TX_SIZE	0x9C		//  				
#define PSC3_RX_SIZE	0xDC		//  				
#define PSC3_TX_STAT	0x88		//  				
#define PSC3_RX_STAT	0xC8		//  				
#define PSC3_TX_DATA	0xBC		//  				
#define PSC3_RX_DATA	0xFC		//  				





















// UART_RXD - Receiver Register
#define UART_RXD_CHRDY			BIT15		// 1 = Character Ready
#define UART_RXD_RXOK			BIT14		// 1 = Recive character has no error
#define UART_RXD_OVR			BIT13		// 1 = Rx fifo overrun
#define UART_RXD_FRAME			BIT12		// 1 = Framing error
#define UART_RXD_BRK			BIT11		// 1 = current character is a break
#define UART_RXD_PAR			BIT10		// 1 = current character has a Parity Error
#define UART_RXD_DATA_MASK		0xff		// received data byte

// UART_TXD - Transmitter Register
#define UART_TXD_DATA(_x_)		((_x_ & 0xff) << 0)	// Transmit Data

// UART_CR1 - Control Register 1 				
#define UART_CR1_ADEN			BIT15		// 1 = Enable the automatic baud rate detection interrupt
#define UART_CR1_ADBR			BIT14		// 1 = Enable automatic detection of baud rate
#define UART_CR1_TRDYEN			BIT13		// 1 = Enable the transmitter ready interrupt
#define UART_CR1_IDEN			BIT12		// 1 = Enable the IDLE bit interrupt
#define UART_CR1_ICD4			(0 << 10)	// 0 = Idle interrupt after 4 frames
#define UART_CR1_ICD8			(1 << 10)	// 1 = Idle interrupt after 8 frames
#define UART_CR1_ICD16			(2 << 10)	// 2 = Idle interrupt after 16 frames
#define UART_CR1_ICD32			(3 << 10)	// 3 = Idle interrupt after 32 frames
#define UART_CR1_RRDYEN			BIT9		// 1 = Enable the RRDY interrupt
#define UART_CR1_RDMAEN			BIT8		// 1 = Enable UART_RX_DMAREQ DMA request
#define UART_CR1_IREN			BIT7		// 1 = Enable the IR interface
#define UART_CR1_TXMPTYEN		BIT6		// 1 = Enable the transmitter FIFO empty interrupt
#define UART_CR1_RTSDEN			BIT5		// 1 = Enable RTSD interrupt
#define UART_CR1_SNDBRK			BIT4		// 1 = Send a BREAK character (continuous 0s)
#define UART_CR1_TDMAEN			BIT3		// 1 = Enable transmit DMA request
#define UART_CR1_UARTCLKEN		BIT2		// 1 = Enable UART clocks
#define UART_CR1_DOZE			BIT1		// 1 = The UART is disabled when in DOZE state
#define UART_CR1_UARTEN			BIT0		// 1 = Enable the UART

// UART_CR2 - Control Register 2 				
#define UART_CR2_ESCI			BIT15		// 1 = Enable the escape sequence interrupt
#define UART_CR2_IRTS			BIT14		// 1 = Transmit regardless of the UARTx_RTS pin state
#define UART_CR2_CTSC			BIT13		// 1 = The UARTx_CTS pin is controlled by the receiver
#define UART_CR2_CTS			BIT12		// Drives UARTx_CTS pin (inverted) when CTSC bit is low
#define UART_CR2_ESCEN			BIT11		// 1 = Enable escape sequence detection
#define UART_CR2_RTEC_HI		0x00 << 9	// 0 = RTS interrupts on rising edge
#define UART_CR2_RTEC_LO		0x01 << 9	// 1 = RTS interrupts on falling edge
#define UART_CR2_RTEC_ANY		0x02 << 9	// 2 = RTS interrupts on either edge
#define UART_CR2_PREN			BIT8		// 1 = Enable parity generator and checker
#define UART_CR2_PROE			BIT7		// 1 = Generate Odd parity
#define UART_CR2_STPB			BIT6		// 0 = 1 stop bit, 1 = 2 stop bits
#define UART_CR2_WS				BIT5		// 0 = 7-bit data length, 1 = 8-bit
#define UART_CR2_RTSEN			BIT4		// 1 = Enable request to send interrupt
#define UART_CR2_ATEN			BIT3		// 1 = Aging timer interrupt enable
#define UART_CR2_TXEN			BIT2		// 1 = Enable the transmitter
#define UART_CR2_RXEN			BIT1		// 1 = Enable the receiver
#define UART_CR2_SRST			BIT0		// 0 = Reset the state machines, FIFOs and all status registers

// UART_UCR3 - Control Register 3 				
#define UART_CR3_DTEC_HI		(0 << 14)	// 0 = DTR Interrupt generated on rising edge
#define UART_CR3_DTEC_LO		(1 << 14)	// 1 = DTR Interrupt generated on falling edge
#define UART_CR3_DTEC_ANY		(2 << 14)	// 2 = DTR Interrupt generated on either edge
#define UART_CR3_DTREN			BIT13		// 1 = Enable the data terminal ready interrupt
#define UART_CR3_PARERREN		BIT12		// 1 = Enable the parity error interrupt
#define UART_CR3_FRAERREN		BIT11		// 1 = Enable the frame error interrupt
#define UART_CR3_DSR			BIT10		// Directly drives the DSR Pin
#define UART_CR3_DCD			BIT9		// Directly drives the DCD Pin
#define UART_CR3_RI				BIT8		// Directly drives the RI Pin
#define UART_CR3_ADNIMP			BIT7		// 1 = Keep old autobaud detection mechanism
#define UART_CR3_RXDSEN			BIT6		// 1 = Enable the Receive Data Status (RXDS) interrupt
#define UART_CR3_AIRINTEN		BIT5		// 1 = Enable the AIRINT interrupt
#define UART_CR3_AWAKEN			BIT4		// 1 = Enable the AWAKE interrupt
#define UART_CR3_REF25			BIT3		// 1 = 25 MHz reference clock used
#define UART_CR3_RXDMUXSEL		BIT2		// 1 = RXD pin goes to UART, 0 = IrDA
#define UART_CR3_INVT			BIT1		// 1 = Invert Infrared Transmision Pulses
#define UART_CR3_ACIEN			BIT0		// 1 = ACST interrupt enabled, 0 = disabled

// UART_CR4 - Control Register 4 				
#define UART_CR4_CTSTL(_x_)	((_x_ & 0x3f) << 10) // CTS deassertion threshold (# of bytes in RxFIFO - 32 max.)
#define UART_CR4_INVR			BIT9		// 0 = Active low IR Receieve detection, 1 =  Active High
#define UART_CR4_ENIRI			BIT8		// 1 = Serial infrared Interrupt enabled
#define UART_CR4_WKEN			BIT7		// 1 = Enable the WAKE interrupt
//#define UART_CR4_REF16			BIT6		// 1 = 16 MHz reference clock is used
#define UART_CR4_LPBYP			BIT5		// 0 = Low power features enabled, 1 = disabled
#define UART_CR4_TCEN			BIT3		// 1 = Enable Transmit Data Complete (TXDC) interrupt
#define UART_CR4_BKEN			BIT2		// 1 = Enable the Break Condition (BRKN) interrupt
#define UART_CR4_OREN			BIT1		// 1 = Enable Overrun (ORE) interrupt
#define UART_CR4_DREN			BIT0		// 1 = Enable Receive Data Ready (RDR) interrupt

// UART_FCR - FIFO Control Register 			
#define UART_FCR_TXTL(_x_)		((_x_ & 0x3f) << 10) // Transmit Fifo threshold (32 max.)
#define UART_FCR_RFDIV6			(0 << 7)	// 0 = Divide input clock by 6
#define UART_FCR_RFDIV5			(1 << 7)	// 1 = Divide input clock by 5
#define UART_FCR_RFDIV4			(2 << 7)	// 2 = Divide input clock by 4
#define UART_FCR_RFDIV3			(3 << 7)	// 3 = Divide input clock by 3
#define UART_FCR_RFDIV2			(4 << 7)	// 4 = Divide input clock by 2
#define UART_FCR_RFDIV1			(5 << 7)	// 5 = Divide input clock by 1
#define UART_FCR_RFDIV7			(6 << 7)	// 6 = Divide input clock by 7
#define UART_FCR_DCEDTE			BIT6		// 0 = DCE mode selected, 1 = DTE mode selected
#define UART_FCR_RXTL(_x_)		((_x_ & 0x3f) << 0) // Receive Fifo threshold (32 max.)

// UART_SR1 - Status Register 1 				
#define UART_SR1_PARITYERR		BIT15		// 1 = Parity error detected (write 1 to clear)
#define UART_SR1_RTSS			BIT14		// RTS Status (inverted)
#define UART_SR1_TRDY			BIT13		// 1 = The transmitter requires data (interrupt posted)
#define UART_SR1_RTSD			BIT12		// 1 = UARTx_RTS pin changed state since last clear (write 1 to clear)
#define UART_SR1_ESCF			BIT11		// 1 = Escape sequence detected (write 1 to clear)
#define UART_SR1_FRAMERR		BIT10		// 1 = Frame error detected (write 1 to clear)
#define UART_SR1_RRDY			BIT9		// 1 = RX Character(s) ready (interrupt posted)
#define UART_SR1_AGTIM			BIT8		// 1 = AGTIM is active, 0 = not active
#define UART_SR1_RXDS			BIT6		// 1 = Receiver is IDLE
#define UART_SR1_AIRINT			BIT5		// 1 = A pulse was detected on the RXD pin (infrared mode only)
#define UART_SR1_AWAKE			BIT4		// 1 = A falling edge was detected on the RXD pin

// UART_SR2 - Status Register 2 				
#define UART_SR2_ADET			BIT15		// 1 = ASCII 'A' or 'a' was received (write 1 to clear)
#define UART_SR2_TXFE			BIT14		// 1 = The transmit buffer (TxFIFO) is empty
#define UART_SR2_DTRF			BIT13		// 1 = Programmed edge detected on UART2_DTR (write 1 to clear, UART2 only)
#define UART_SR2_IDLE			BIT12		// 1 = Idle condition detected (write 1 to clear)
#define UART_SR2_ACST			BIT11		// 1 = Measurement of bit length finished, 0 = not finished, (in autobaud)
#define UART_SR2_RIDELT			BIT10		// 1 = Ring indicator input has changed state, 0 = not changed state
#define UART_SR2_RIIN			BIT9		// 1 = No ring detected, 0 = detected
#define UART_SR2_IRINT			BIT8		// 1 = valid edge detected, infrared mode only (write 1 to clear)
#define UART_SR2_WAKE			BIT7		// 1 = start bit detected (write 1 to clear)
#define UART_SR2_DCDDELT		BIT6		// 1 = Data Carrier Detect input has changed state, 0 = Not changed state
#define UART_SR2_DCDIN			BIT5		// 1 = No carrier signal detected, 0 = detected
#define UART_SR2_RTSF			BIT4		// 1 = Programmed edge detected on RTS (write 1 to clear)
#define UART_SR2_TXDC			BIT3		// 1 = Transmit is complete
#define UART_SR2_BRCD			BIT2		// 1 = A BREAK condition was detected (write 1 to clear)
#define UART_SR2_ORE			BIT1		// 1 = Overrun error (write 1 to clear)
#define UART_SR2_RDR			BIT0		// 1 = Receive data ready

// UART_ESC - Escape Character Register 		
#define UART_ESC_MASK			0xff

// UART_TIM - Escape Timer Register 			
#define UART_TIM_MASK			0xfff

// UART_BIR  - BRM Incremental Register			
#define UART_BIR_MASK			0xffff

// UART_BMR - BRM Modulator Register 			
#define UART_BMR_MASK			0xffff

// UART_BRC - Baud Rate Count Register 			
#define UART_BRC_MASK			0xffff

// UART_ONEMS - One Millisecond Register 			
#define UART_ONEMS_MASK			0xffff

